## Diengine Connect

A suite of Python packages for connecting Python to ClickHouse:
* Pandas DataFrames
* Numpy Arrays
* PyArrow Tables
* SQLAlchemy 1.3 and 1.4 (limited feature set)
* Apache Superset 1.4+


### Installation

```
pip install diengine-connect
```

Diengine Connect requires Python 3.7 or higher.  
